import { DeviceCartDrawer } from "@/components/device-cart";
import { Wallet } from "@/components/wallet";

import { ModeToggle } from "@/components/theme-toggle";
import { AppSidebar } from "@/components/ui/app-sidebar";

import { authOptions } from "@/app/auth";
import { Separator } from "@/components/ui/separator";
import {
	SidebarInset,
	SidebarProvider,
	SidebarTrigger,
} from "@/components/ui/sidebar";
import { getServerSession } from "next-auth";
import { headers } from "next/headers";
import { AccountPopover } from "./account-popver";

export async function ApplicationLayout({
	children,
}: { children: React.ReactNode }) {
	const session = await getServerSession(authOptions);

	return (
		<SidebarProvider>
			<AppSidebar role={"admin"} />
			{/* <DeviceCartDrawer billFormula={billFormula || null} /> */}
			<SidebarInset>
				<header className="flex justify-between sticky top-0 bg-background h-16 shrink-0 items-center gap-2 border-b px-4 z-10">
					<div className="flex items-center gap-2 ">
						<SidebarTrigger className="-ml-1" />
						<Separator orientation="vertical" className="mr-2 h-4" />
						{session?.user.role === "ADMIN" && (
							<span className="text-sm font-mono px-2 p-1 rounded-md bg-green-500/10 text-green-900 dark:text-green-400">
								Welcome back {session?.user.name}
							</span>
						)}
					</div>

					<div className="flex items-center gap-2">
						{/* <Wallet walletBalance={user?.walletBalance || 0} /> */}
						<ModeToggle />
						<AccountPopover />
					</div>
				</header>
				<div className="p-4 flex flex-col flex-1">{children}</div>
			</SidebarInset>
		</SidebarProvider>
	);
}
